# Firmware von Freifunk Hochstift

Dieses Repository beherbergt die Skripte, um die Firmware von Freifunk Hochstift zu bauen.
Die Inhalte dieses Repositories werden unter einer "2-clause BSD" Lizenz veröffentlicht, Details sind der Datei [LICENSE](https://git.c3pb.de/freifunk-pb/firmware/blob/master/LICENSE) zu entnehmen.

Beim Bauen der Firmware werden weitere Git-Repositories heruntergeladen und benutzt:

* Basis: [Gluon](https://github.com/freifunk-gluon/gluon)
* Site-Repository: [FFHO](https://git.c3pb.de/freifunk-pb/site-ffho)

## Vorbereitung / Umgebung

Für das Build-System werden die gennerell für Gluon notwendigen Pakete, sowie lua5.1 benötigt.
```bash
sudo apt-get install git subversion python build-essential gawk unzip libncurses-dev \
  libz-dev libssl-dev lua5.1
```

## Bauen

Klone das Repository in dem diese ReadMe liegt, falls noch nicht geschehen und wechsle in das Verzeichnis:
```bash
git clone https://git.c3pb.de/freifunk-pb/firmware.git
cd firmware
```

Rufe `build.sh` bzw. `docker-build.sh` auf und übergebe folgende Umgebungsvariablen:

* **BASE** gibt die Gluon-Version an, die als Basis benutzt werden soll (z.B. 'v2014.4')
* **BRANCH** ist der Name des Firmware-Branches (also 'stable', 'testing' oder 'experimental')
* **VERSION** wird die Versions-Nr. der neuen Firmware (kann bei BRANCH=experimental weggelassen werden)

optional:
* **AUTOUPDATER** setzt den Autoupdater auf einen anderen Branch als bei **BRANCH** angegeben ('stable', 'testing', 'experimental' oder 'off', default: **BRANCH**)
* **BROKEN** falls "1", erzeuge zusätzlich Firmware-Images für ungetestete Plattformen (default: "0")
* **BUILD_TS** setzt den Zeitstempel für den Build-Prozess (format: %Y-%m-%d %H:%M:%S)
* **CLEAN** falls "dirclean", wird `make dirclean` ausgeführt, falls "clean" wird `make clean` ausgeführt, ansonsten keins von beidem (BRANCH=stable/testing default: "clean", BRANCH=experimental default: "none")
* **KEY_DIR** gibt das Verzeichnis für gluon-opkg-key an (default: ./opkg-keys)
* **MAKEJOBS** spezifiziert die Anzahl der parallel laufenden Compiler-Prozesse (default: ein Prozess pro CPU/Kern)
* **PRIORITY** spezifiziert die maximale Anzahl an Tagen, die ein Knoten das Einspielen des Updates verzögern darf (default: $(DEFAULT_GLUON_PRIORITY))
* **PUBLISH** falls "1", veröffentliche die Firmware nach dem bauen
* **SITE_ID** gibt die Commit-ID des Site-Repos an (default: HEAD)
* **SITE_REPO_FETCH_METHOD** wählt die Methode zum Klonen des Site-Repos ('git' oder 'http', default: 'http')
* **TARGETS** ein Liste durch Leerzeichen separierter Hardware-Zielplattformen (default: alle bekannten Plattformen)
* **VERBOSE** falls "1", schaltet Debug-Ausgaben mit an - dies ist nur notwendig wenn Fehler beim Build auftreten (default: "0")
* **VERSIONS_DIR** gibt das Verzeichnis für die Versions-Dateien an (default: ./versions)


### Beispiele

```bash
# Baut eine testing-Firmware auf Basis von Gluon 2014.4
BASE=v2014.4 BRANCH=testing VERSION=0.6~rc1 ./build.sh

# Baut eine experimental-Firmware auf Basis des aktuellen Gluon-Master (nur für Experten)
BASE=master BRANCH=experimental ./build.sh
```

Nach erfolgreichem Build-Vorgang liegt die Firmware fertig paketiert im `output/` Verzeichnis und in `versions/` wurde (außer bei BRANCH=experimental) eine Versions-Informationsdatei abgelegt. Mit dieser (nur der Name) kann `build-version.sh` die gegebene Version erneut bauen.


## Kontroll-Build einer Firmware

Klone das Repository in dem diese ReadMe liegt, falls noch nicht geschehen und wechsle in das Verzeichnis:
```bash
git clone https://git.c3pb.de/freifunk-pb/firmware.git
cd firmware
```

Durch Aufruf von `build-version.sh` und Übergabe des Versions-Datei kann eine Firmware erneut gebaut werden. Es werden folgende Umgebungsvariablen optional unterstützt:
* **BROKEN** falls "1", erzeuge zusätzlich Firmware-Images für ungetestete Plattformen (default: "0")

### Beispiele

```bash
./build_version.sh ./versions/0.7.4 # baut Version '0.7.4' erneut
```
